function card_init(user, props)
	local action = Action.new(user, "CHARACTER_SWING")
	local SLASH_TEXTURE = Resources.load_texture("spell_sword_slashes.png")
	--Specially time the sword arm attack.
	local frame1 = { 4, 3 }
	local frame2 = { 3, 2 }
	local frame3 = { 2, 2 }
	local frame4 = { 1, 9 }
	--Override the animation.
	local frame_override = { frame1, frame2, frame3, frame4 }
	action:override_animation_frames(frame_override)
	action:set_lockout(ActionLockout.new_animation())
	action.on_execute_func = function(self, user)
		self:add_anim_action(1, function()
			--When we create the attachment, we want to grab the sprite as well.
			local hilt = self:create_attachment("HILT")
			local hilt_sprite = hilt:sprite()
			hilt_sprite:set_texture(user:texture())
			hilt_sprite:set_layer(-2)
			--Set the shader so it mimics the pallet.
			hilt_sprite:use_root_shader(true)

			local hilt_anim = hilt:animation()
			hilt_anim:copy_from(user:animation())
			hilt_anim:set_state("HAND")
			--Refresh so it's frame perfect.
			hilt_anim:apply(hilt_sprite)
			--Reverse the animation to play properly with the frame override we used.
			hilt_anim:set_playback(Playback.Reverse)
		end)

		self:add_anim_action(3, function()
			--Create the wide sword.
			local sword = create_slash(user, props)
			--Grab the tile directly ahead of us in the direction we're facing.
			local tile = user:get_tile(user:facing(), 1)
			--Make two shared hitboxes that share the properties of the sword.
			local sharebox1 = SharedHitbox.new(sword, 9)
			sharebox1:set_hit_props(sword:copy_hit_props())
			local sharebox2 = SharedHitbox.new(sword, 9)
			sharebox2:set_hit_props(sword:copy_hit_props())
			--Spawn all three attacks.
			user:field():spawn(sharebox1, tile:get_tile(Direction.Up, 1))
			user:field():spawn(sword, tile)
			user:field():spawn(sharebox2, tile:get_tile(Direction.Down, 1))
			--Create a spell to animate the slash.
			local fx = Spell.new(user:team())
			fx:set_facing(sword:facing())
			local anim = fx:animation()
			--Give it its texture and animation.
			fx:set_texture(Resources.load_texture("spell_sword_slashes.png"), true)
			anim:load("spell_sword_slashes.animation")
			anim:set_state("WIDE")
			--Reverse it too, so that its animation makes sense with the downswing we're making.
			anim:set_playback(Playback.Reverse)
			--Delete the animation and attack
			anim:on_complete(function()
				fx:erase()
				--if the sword didn't delete on impact then get rid of it.
				if not sword:deleted() then sword:erase() end
			end)
			user:field():spawn(fx, tile)
		end)
	end
	return action
end

function create_slash(user, props)
	local spell = Spell.new(user:team())
	spell:set_facing(user:facing())
	spell:set_tile_highlight(Highlight.Flash)
	spell:set_hit_props(props)
	spell.on_update_func = function(self)
		--Highlight the tiles up and down.
		local tile = self:current_tile()
		if not tile:get_tile(Direction.Up, 1):is_edge() then
			tile:get_tile(Direction.Up, 1):set_highlight(Highlight
				.Flash)
		end
		if not tile:get_tile(Direction.Down, 1):is_edge() then
			tile:get_tile(Direction.Down, 1):set_highlight(Highlight
				.Flash)
		end
		tile:attack_entities(self)
	end
	spell.on_collision_func = function(self, other)
		self:erase()
	end
	spell.can_move_to_func = function(tile)
		return true
	end

	Resources.play_audio(Resources.load_audio("sfx.ogg"))

	return spell
end
